@@ -60,6 +60,4 @@ class Notification(Device):
 
     def __str__(self) -> str:
         """Return object as readable string."""
-        return '<Notification name="{}" message={} />'.format(
-            self.name, self._message.group_addr_str()
-        )
+        return f'<Notification name="{self.name}" message={self._message.group_addr_str()} />'
