@@ -71,4 +71,4 @@ class RemoteValueControl(RemoteValue[DPTBinary, Any]):
     @property
     def ha_device_class(self) -> str | None:
         """Return a string representing the home assistant device class."""
-        return getattr(self.dpt_class, "ha_device_class", None)  # type: ignore
+        return getattr(self.dpt_class, "ha_device_class", None)
