@@ -9,3 +9,12 @@ Module for handling KNX primitves.
 from .address import GroupAddress, GroupAddressType, IndividualAddress
 from .address_filter import AddressFilter
 from .telegram import Telegram, TelegramDirection
+
+__all__ = [
+    "AddressFilter",
+    "GroupAddress",
+    "GroupAddressType",
+    "IndividualAddress",
+    "Telegram",
+    "TelegramDirection",
+]
